@@ -20,6 +20,7 @@ def checkbox(
     qmark: Text = DEFAULT_QUESTION_PREFIX,
     style: Optional[Style] = None,
     use_pointer: bool = True,
+    initial_choice: Optional[Union[Text, Choice, Dict[Text, Any]]] = None,
     **kwargs: Any
 ) -> Question:
     """Ask the user to select from a list of items.
@@ -47,13 +48,18 @@ def checkbox(
         use_pointer: Flag to enable the pointer in front of the currently
                      highlighted element.
 
+        initial_choice: A value corresponding to a selectable item in the choices,
+                        to initially set the pointer position to.
+
     Returns:
         Question: Question instance, ready to be prompted (using `.ask()`).
     """
 
     merged_style = merge_styles([DEFAULT_STYLE, style])
 
-    ic = InquirerControl(choices, default, use_pointer=use_pointer)
+    ic = InquirerControl(
+        choices, default, use_pointer=use_pointer, initial_choice=initial_choice
+    )
 
     def get_prompt_tokens():
         tokens = []
