@@ -182,3 +182,31 @@ def test_list_ctr_c():
 
     with pytest.raises(KeyboardInterrupt):
         feed_cli_with_input("checkbox", message, text, **kwargs)
+
+
+def test_checkbox_initial_choice():
+    message = "Foo message"
+    kwargs = {"choices": ["foo", "bazz"], "initial_choice": "bazz"}
+    text = KeyInputs.SPACE + KeyInputs.ENTER + "\r"
+
+    result, cli = feed_cli_with_input("checkbox", message, text, **kwargs)
+    assert result == ["bazz"]
+
+
+def test_checkbox_initial_choice_not_selectable():
+    message = "Foo message"
+    separator = Separator()
+    kwargs = {"choices": ["foo", "bazz", separator], "initial_choice": separator}
+    text = KeyInputs.ENTER + "\r"
+
+    with pytest.raises(ValueError):
+        feed_cli_with_input("checkbox", message, text, **kwargs)
+
+
+def test_checkbox_initial_choice_non_existant():
+    message = "Foo message"
+    kwargs = {"choices": ["foo", "bazz"], "initial_choice": "bar"}
+    text = KeyInputs.ENTER + "\r"
+
+    with pytest.raises(ValueError):
+        feed_cli_with_input("checkbox", message, text, **kwargs)
